==> kolourpaint-17.07.90.tar.xz: kolourpaint-17.07.90/tools/polygonal/kpToolPolygon.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_POLYGON_H
#define KP_TOOL_POLYGON_H


#include "kpToolPolygonalBase.h"


class kpToolPolygon : public kpToolPolygonalBase
{
Q_OBJECT

public:
    kpToolPolygon (kpToolEnvironment *environ, QObject *parent);
    virtual ~kpToolPolygon ();

private:
    QString haventBegunShapeUserMessage () const Q_DECL_OVERRIDE;

public:
    void begin () Q_DECL_OVERRIDE;
    void end () Q_DECL_OVERRIDE;

protected:
    kpColor drawingBackgroundColor () const Q_DECL_OVERRIDE;

public:
    void endDraw (const QPoint &, const QRect &) Q_DECL_OVERRIDE;

private:
    struct kpToolPolygonPrivate *d;
};


#endif  // KP_TOOL_POLYGON_H

==> kolourpaint_21.12.3.orig.tar.xz: kolourpaint-21.12.3/tools/polygonal/kpToolPolygon.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_POLYGON_H
#define KP_TOOL_POLYGON_H


#include "kpToolPolygonalBase.h"


class kpToolPolygon : public kpToolPolygonalBase
{
Q_OBJECT

public:
    kpToolPolygon (kpToolEnvironment *environ, QObject *parent);
    ~kpToolPolygon () override;

private:
    QString haventBegunShapeUserMessage () const override;

public:
    void begin () override;
    void end () override;

protected:
    kpColor drawingBackgroundColor () const override;

public:
    void endDraw (const QPoint &, const QRect &) override;

private:
    struct kpToolPolygonPrivate *d;
};


#endif  // KP_TOOL_POLYGON_H
